@@ -36,18 +36,16 @@
 /*	queue IDs from standard input. For example, to delete all mail
 /*	with exactly one recipient \fBuser@example.com\fR:
 /* .sp
+/* .nf
 /*	mailq | tail +2 | grep -v '^ *(' | awk  \'BEGIN { RS = "" }
-/* .ti +4
-/*	# $7=sender, $8=recipient1, $9=recipient2
-/* .ti +4
-/*	{ if ($8 == "user@example.com" && $9 == "")
-/* .ti +10
-/*	print $1 }
-/* .br
+/*	    # $7=sender, $8=recipient1, $9=recipient2
+/*	    { if ($8 == "user@example.com" && $9 == "")
+/*	          print $1 }
 /*	\' | tr -d '*!' | postsuper -d -
+/* .fi
 /* .sp
-/*	Specify \fB-d ALL\fR to remove all messages; for example, specify
-/*	\fB-d ALL deferred\fR to delete mail in the \fBdeferred\fR queue.
+/*	Specify "\fB-d ALL\fR" to remove all messages; for example, specify
+/*	"\fB-d ALL deferred\fR" to delete all mail in the \fBdeferred\fR queue.
 /*	As a safety measure, the word \fBALL\fR must be specified in upper
 /*	case.
 /* .sp
@@ -81,8 +79,8 @@
 /*	If a \fIqueue_id\fR of \fB-\fR is specified, the program reads
 /*	queue IDs from standard input.
 /* .sp
-/*	Specify \fB-h ALL\fR to hold all messages; for example, specify
-/*	\fB-h ALL deferred\fR to hold mail in the \fBdeferred\fR queue.
+/*	Specify "\fB-h ALL\fR" to hold all messages; for example, specify
+/*	"\fB-h ALL deferred\fR" to hold all mail in the \fBdeferred\fR queue.
 /*	As a safety measure, the word \fBALL\fR must be specified in upper
 /*	case.
 /* .sp
@@ -98,11 +96,11 @@
 /*	If a \fIqueue_id\fR of \fB-\fR is specified, the program reads
 /*	queue IDs from standard input.
 /* .sp
-/*	Note: use "\fBpostsuper -r\fR" to release mail that was kept on
+/*	Note: specify "\fBpostsuper -r\fR" to release mail that was kept on
 /*	hold for a significant fraction of \fB$maximal_queue_lifetime\fR
 /*	or \fB$bounce_queue_lifetime\fR, or longer.
 /* .sp
-/*	Specify \fB-H ALL\fR to release all mail that is "on hold".
+/*	Specify "\fB-H ALL\fR" to release all mail that is "on hold".
 /*	As a safety measure, the word \fBALL\fR must be specified in upper
 /*	case.
 /* .IP \fB-p\fR
@@ -118,16 +116,34 @@
 /*	Alternatively, if a \fIqueue_id\fR of \fB-\fR is specified,
 /*	the program reads queue IDs from standard input.
 /* .sp
-/*	Specify \fB-r ALL\fR to requeue all messages. As a safety
+/*	Specify "\fB-r ALL\fR" to requeue all messages. As a safety
 /*	measure, the word \fBALL\fR must be specified in upper case.
 /* .sp
-/*	A requeued message is moved to the \fBmaildrop\fR queue, from
-/*	where it is copied by the pickup daemon to a new file whose name
-/*	is guaranteed to match the new queue file inode number. The
-/*	new queue file is subjected again to mail address rewriting and
-/*	substitution. This is useful when rewriting rules or virtual
-/*	mappings have changed.
+/*	A requeued message is moved to the \fBmaildrop\fR queue,
+/*	from where it is copied by the \fBpickup\fR(8) and
+/*	\fBcleanup\fR(8) daemons to a new queue file. In many
+/*	respects its handling differs from that of a new local
+/*	submission.
+/* .RS
+/* .IP \(bu
+/*	The message is not subjected to the smtpd_milters or
+/*	non_smtpd_milters settings.  When mail has passed through
+/*	an external content filter, this would produce incorrect
+/*	results with Milter applications that depend on original
+/*	SMTP connection state information.
+/* .IP \(bu
+/*	The message is subjected again to mail address rewriting
+/*	and substitution.  This is useful when rewriting rules or
+/*	virtual mappings have changed.
 /* .sp
+/*	The address rewriting context (local or remote) is the same
+/*	as when the message was received.
+/* .IP \(bu
+/*	The message is subjected to the same content_filter settings
+/*	(if any) as used for new local mail submissions.  This is
+/*	useful when content_filter settings have changed.
+/* .RE
+/* .IP
 /*	Warning: Postfix queue IDs are reused.
 /*	There is a very small possibility that \fBpostsuper\fR(1) requeues
 /*	the wrong message file when it is executed while the Postfix mail
@@ -235,6 +251,7 @@
 #include <mail_task.h>
 #include <mail_conf.h>
 #include <mail_params.h>
+#include <mail_version.h>
 #include <mail_queue.h>
 #include <mail_open_ok.h>
 
@@ -970,6 +987,8 @@ static void fatal_warning(void)
     interrupted(0);
 }
 
+MAIL_VERSION_STAMP_DECLARE;
+
 int     main(int argc, char **argv)
 {
     int     fd;
@@ -1013,6 +1032,11 @@ int     main(int argc, char **argv)
 	0,
     };
 
+    /*
+     * Fingerprint executables and core dumps.
+     */
+    MAIL_VERSION_STAMP_ALLOCATE;
+
     /*
      * Be consistent with file permissions.
      */
@@ -1120,6 +1144,8 @@ int     main(int argc, char **argv)
      * configuration directory location.
      */
     mail_conf_read();
+    if (strcmp(var_syslog_name, DEF_SYSLOG_NAME) != 0)
+	msg_syslog_init(mail_task(argv[0]), LOG_PID, LOG_FACILITY);
     if (chdir(var_queue_dir))
 	msg_fatal("chdir %s: %m", var_queue_dir);
 
